@@ -560,11 +560,7 @@ function_sparql_regex (sqlite3_context *context,
 		sqlite3_set_auxdata (context, 1, regex, (void (*) (void*)) g_regex_unref);
 	}
 
-	if (text != NULL) {
-		ret = g_regex_match (regex, text, 0, NULL);
-	} else {
-		ret = FALSE;
-	}
+	ret = g_regex_match (regex, text, 0, NULL);
 
 	sqlite3_result_int (context, ret);
 }
@@ -1291,6 +1287,12 @@ tracker_db_interface_sqlite_fts_delete_text (TrackerDBInterface *db_interface,
 	return TRUE;
 }
 
+void
+tracker_db_interface_sqlite_fts_rebuild_tokens (TrackerDBInterface *interface)
+{
+	tracker_fts_rebuild_tokens (interface->db, "fts");
+}
+
 #endif
 
 void
