@@ -46,9 +46,11 @@ tracker_encoding_can_guess (void)
 
 gchar *
 tracker_encoding_guess (const gchar *buffer,
-                        gsize        size)
+                        gsize        size,
+                        gdouble     *confidence)
 {
 	gchar *encoding = NULL;
+	gdouble conf = 1;
 
 #ifdef HAVE_MEEGOTOUCH
 	encoding = tracker_encoding_guess_meegotouch (buffer, size);
@@ -56,14 +58,18 @@ tracker_encoding_guess (const gchar *buffer,
 
 #ifdef HAVE_LIBICU_CHARSET_DETECTION
 	if (!encoding)
-		encoding = tracker_encoding_guess_icu (buffer, size);
+		encoding = tracker_encoding_guess_icu (buffer, size, &conf);
 #endif /* HAVE_LIBICU_CHARSET_DETECTION */
 
 #ifdef HAVE_ENCA
-	if (!encoding)
+	if (!encoding || conf < 0.5) {
+		conf = 1;
 		encoding = tracker_encoding_guess_enca (buffer, size);
+	}
 #endif /* HAVE_ENCA */
 
+	if (confidence)
+		*confidence = conf;
 
 	return encoding;
 }
